---
description: Review thd OASP Definition
argument-hint: [doc]
model: opus
---

结合当前的代码实现，判断一下 $1 中的OASP协议定义的请求参数，返回结构等是否与实现一致，因为 OASP 文档做过一次迁移，中间产生了一些变动，因此担心文档结构与当前代码实现无法保证一致，因此需要二次确认。

一般情况下以代码为主，但如果遇到代码实现极不合理的地方，也可以与我沟通，修正代码实现。同时注意代码的真实返回结构需要在协议层来最终判断，因为在内部实现可能缺少一些标准字段的包装。

如果协议定义有问题，出具一个修复建议文档，我会交付给协议维护者，责令修改。